@@ -1,18 +1,24 @@
 /*
     Copyright (C) 2017 Volker Krause <vkrause@kde.org>
 
-    This program is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
+    Permission is hereby granted, free of charge, to any person obtaining
+    a copy of this software and associated documentation files (the
+    "Software"), to deal in the Software without restriction, including
+    without limitation the rights to use, copy, modify, merge, publish,
+    distribute, sublicense, and/or sell copies of the Software, and to
+    permit persons to whom the Software is furnished to do so, subject to
+    the following conditions:
 
-    This program is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
+    The above copyright notice and this permission notice shall be included
+    in all copies or substantial portions of the Software.
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+    EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+    IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+    CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+    TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+    SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
 
 #ifndef KUSERFEEDBACK_PROVIDER_P_H
@@ -32,6 +38,7 @@
 
 QT_BEGIN_NAMESPACE
 class QNetworkAccessManager;
+class QNetworkReply;
 class QSettings;
 QT_END_NAMESPACE
 
@@ -55,9 +62,11 @@ public:
 
     bool isValidSource(AbstractDataSource *source) const;
     QByteArray jsonData(Provider::TelemetryMode mode) const;
-    void scheduleNextSubmission();
+    void scheduleNextSubmission(qint64 minTime = 0);
+    void submitProbe(const QUrl &url);
+    void submitProbeFinished(QNetworkReply *reply);
     void submit(const QUrl &url);
-    void submitFinished();
+    void submitFinished(QNetworkReply *reply);
 
     bool selectSurvey(const SurveyInfo &survey) const;
 
@@ -67,7 +76,7 @@ public:
 
     void writeAuditLog(const QDateTime &dt);
 
-    QVariant sourceData(const QString &sourceName) const override;
+    QVariant sourceData(const QString &sourceId) const override;
 
     Provider *q;
 
@@ -96,7 +105,10 @@ public:
     int encouragementDelay;
     int encouragementInterval;
 
+    int backoffIntervalMinutes;
+
     QVector<AbstractDataSource*> dataSources;
+    QHash<QString, AbstractDataSource*> dataSourcesById;
 };
 }
 
