@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2020 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2021 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Christoph Sterz <christoph.sterz@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -145,7 +145,7 @@ QuickSceneControlWidget::QuickSceneControlWidget(QuickInspectorInterface *inspec
     m_visualizeTraces->setData(QuickInspectorInterface::VisualizeTraces);
     m_visualizeTraces->setCheckable(true);
     m_visualizeTraces->setToolTip(tr("<b>Visualize Controls</b><br>"
-                                     "The QtQuick scene is rendered normaly, in addition overlays will "
+                                     "The QtQuick scene is rendered normally, in addition overlays will "
                                      "highlight Qt Quick Controls."));
 
     m_serverSideDecorationsEnabled = new QAction(UIResources::themedIcon(QLatin1String("server-decorations.png")),
