@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2016-2020 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2016-2021 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -29,9 +29,9 @@
 #include <core/enumutil.h>
 #include <core/enumrepositoryserver.h>
 
-#include <QtTest/qtest.h>
 #include <QFrame>
 #include <QObject>
+#include <QTest>
 
 Q_DECLARE_METATYPE(const QMetaObject *)
 Q_DECLARE_METATYPE(QSizePolicy::ControlTypes)
