@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2016-2020 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2016-2021 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -42,7 +42,7 @@
 #include <QObject>
 #include <QSignalSpy>
 #include <QThread>
-#include <QtTest/qtest.h>
+#include <QTest>
 
 using namespace GammaRay;
 using namespace TestHelpers;
