@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2020 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2021 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -28,11 +28,11 @@
 
 #include "core/multisignalmapper.h"
 
-#include <QtTest/qtest.h>
-#include <QtTest/qsignalspy.h>
-#include <QObject>
-#include <QVector>
 #include <QDebug>
+#include <QObject>
+#include <QSignalSpy>
+#include <QVector>
+#include <QTest>
 
 using namespace GammaRay;
 
